Skip to contents

This function will extracts the initial states for the differential equations from a NONMEM model

Usage

get_inits(lstblock)

Arguments

lstblock

list with each item being a separate structured dollar block, usually obtain from nmlistblock

Value

a named vector with the state values

Author

Richard Hooijmaijers

Examples


mod    <- system.file("example_models","PK.1CMT.ORAL.mod", package = "amp.sim")
mdll   <- get_nmblock(mod,block=c("PK","DES"))
mdlls  <- nmlistblock(mdll)
get_inits(mdlls)
#>  A1  A2 
#> "0" "0"