R/conv_pow.r
conv_pow.Rd
This function will transform the power notation that can be used in R to the one needed by mrgsolve
conv_pow(x)
character vector with the formulas to convert
a vector with the transformed power notations
Richard Hooijmaijers
conv_pow("y = par1*(par2/par3)^xy + a - par4**(2/par5)") #> [1] "y = par1 * pow((par2/par3), xy) + a - pow(par4, (2/par5))"