Create data.frame with dosing for usage in simulation with deSolve
Source:R/dose_func.r
dose_func.RdThis function creates a data.frame that can be used for events of a deSolve simulation
Arguments
- cmt
number of compartment or differential equation where the dosing should be given
- value
the value of the dosing that should be given
- tinf
in case value is set an infusion is assumed with tinf as infusion time
- tau
dosing interval to be used
- ndose
number of doses to be used
- times
In case tau and ndose cannot be used (unequal dosing), this parameter can be used to set times of dosing (e.g c(0,24,168))