This function wraps around the dput function and provide more options to save result in a vector
Arguments
- x
An object passed to
dput- comment
logical indicating if comment characters should be prepended to results
- obj
character of length one indicating the name of the object that should be prepended to result
- collapse
character of length one with the collapse character. If provided the result will be pasted with this collapse character
- ...
additional arguments passed to dput