This function takes a function that defines a model in analytical solution and performs multiple dosing for it
Details
This function will create a list that can be used to perform superposition
which is necessary in case of an analytical solution in a multiple dose setting.
The function will check if there is an overlap in arguments and will use the arguments
given to mdose for the function given in func if applicable (e.g. it is
likely that func has an argument for Dose, in this case it will use the Dose argument
provide in mdose)
The function can have any number of arguments that can be passed using "...". However there
should at least be an argument t which is the time vector for which simulations are
necessary.